﻿#ifndef __CMCC_CAMERA_H__
#define __CMCC_CAMERA_H__


#ifdef __cplusplus
extern "C"
{
#endif

#if defined(WIN32) || defined(_WIN32) || defined(WIN64) || defined(_WIN64) || defined (_WINDOWS)
#ifndef WIN32_LEAN_AND_MEAN
#define WIN32_LEAN_AND_MEAN
#endif
#ifndef _CRT_SECURE_NO_WARNINGS
#define _CRT_SECURE_NO_WARNINGS
#endif
#include <Windows.h>
#else
typedef struct
{
	long left;
	long top;
	long right;
	long bottom;
}RECT;
typedef void* HWND;
#endif

/* 正常 */
#define CMCC_ERR_OK					0L
/* 设备故障 */
#define CMCC_ERR_DEVICE_FAULT		431001L
/* 端口不存在 */
#define CMCC_ERR_PORT_NOT_EXIST		431002L
/* 端口打开失败 */
#define CMCC_ERR_PORT_OPEN_FAILED	431003L
/* 无响应 */
#define CMCC_ERR_NO_RESPONSE		431004L
/* 数据接收异常 */
#define CMCC_ERR_DATA_RECV_FAILED	431005L
/* 设备打开失败 */
#define CMCC_ERR_DEVICE_OPEN_FAILED	431006L

/* 一般错误 */
#define CMCC_ERR_FAILED				441000L
/* 无法连接设备 */
#define CMCC_ERR_CANNOT_CONNECT_DEVICE	441001L
/* 初始化失败 */
#define CMCC_ERR_INIT_FAILED		441006L
/* 设备访问超时 */
#define CMCC_ERR_DEVICE_TIMEOUT		441007L
/* 检测不到设备 */
#define CMCC_ERR_NO_DEVICE			441008L

/* 设备信息 */
typedef struct
{
	unsigned short devIndex; /* 设备索引, 0：主设备 >=1：副设备 */
	char devDesc[40]; /* 设备描述 */
	char vendorName[56]; /* vid */
	char productName[32]; /* pid */
	char dllVersion[12]; /* dll版本号 */
	unsigned short vendorID; /* vid */
	unsigned short productID; /* pid */
	char serial[20]; /* 设备唯一序列号(可以为空) */
	RECT monitorBounds; /* 屏幕笔迹范围：[left,top,right,bottom] */
	long pressureLevel; /* 压感级别 */
	long deviceType; /* 设备类型, cmcc_camera.so摄像设备:0(摄像头) 1(扫描仪) */
	long intParm1; /* 整型保留字段1, cmcc_camera.so摄像设备：分辨率宽 */
	long intParm2; /* 整型保留字段2, cmcc_camera.so摄像设备：分辨率高 */
	long intParm3; /* 整型保留字段3, cmcc_camera.so摄像设备：分辨率节点 */
	long intParm4; /* 整型保留字段4 */
	char strParm1[20]; /* 字符保留字段1 */
	char strParm2[20]; /* 字符保留字段2 */
	char strParm3[20]; /* 字符保留字段3 */
	char reserved[32]; /* 保留字段 */
}DEVICE_INFO;

typedef struct
{
	float x;
	float y;
}RECTCROP;

typedef struct
{
	RECTCROP* rect; /* 结构体：返回自动裁切数据 */
	char* frame; /* 返回摄像头数据 */
	long frameLen; /* 返回摄像头数据长度 */
	long width; /* 实际返回的分辨率X */
	long height; /* 实际返回的分辨率Y */
}FMIMG_INFO;

typedef struct
{
	long width;
	long height;
}DEVICE_RESOLUTION;

typedef void (*StreamCallback)(FMIMG_INFO* capFrame, void *param);

long getDeviceInfo(long* retNum, DEVICE_INFO* retDID, char* retMsg);

long openDevice(DEVICE_INFO* recDev, char* retMsg);

long getDeviceStatus(DEVICE_INFO* recDev, char* retMsg);

long closeDevice(DEVICE_INFO* recDev, char* retMsg);

long startCapture(HWND hwnd, DEVICE_INFO* recDev, long type, long angle, long width, long height, char* retMsg);

long getCapFrame(DEVICE_INFO* recDev, FMIMG_INFO* capFrame);

long stopCapture(DEVICE_INFO* recDev, char* retMsg);

long startRec(DEVICE_INFO* recDev, long width, long height, long tmRec, char* videoFile, char* retMsg);

long stopRec(DEVICE_INFO* recDev, char* videoFile, char* retMsg);

long photo(DEVICE_INFO* recDev, long type, char* jpgFile, char* retMsg);

long setStreamCallback(DEVICE_INFO* recDev, StreamCallback func, void *param);

long getResolution(DEVICE_INFO* recDev, long type, long* retNum, DEVICE_RESOLUTION *res, char* retMsg);

long setZoom(DEVICE_INFO* recDev, long scale, char* retMsg);

long setAngle(DEVICE_INFO* recDev, long angle, char* retMsg);

#ifdef __cplusplus
}
#endif

#endif /* __CMCC_CAMERA_H__ */